oauth-flow
==========

App for authenticating with OAuth 1.0/2.0 services

 * Twitter
 * Yahoo
 * Facebook (OAuth 2.0)
 * Google (OAuth 2.0)

Used by django-linked-accounts

Inspired by django-social-auth and django-oauth-access.
